==> opstool-0.1.0.tar.gz: opstool-0.1.0/README.md <==
<p align="center">
  <font size=7><a href="https://github.com/yexiang1992/opstool">opstool</a></font>
  <p align="center"><font size=5 color=YellowGreen>modelling, visualization, post-processing for OpenSeesPy.</font></p>
</p>

[![pypi](https://img.shields.io/pypi/v/opstool)](https://pypi.org/project/opstool/)
[![pypi downloads](https://img.shields.io/pypi/dm/opstool)](https://pypi.org/project/opstool/)
[![Documentation Status](https://readthedocs.org/projects/opstool/badge/?version=latest)](https://opstool.readthedocs.io/en/latest/?badge=latest)
[![github stars](https://img.shields.io/github/stars/yexiang1992/opstool?style=social)](https://github.com/yexiang1992/opstool)
![license](https://img.shields.io/github/license/yexiang1992/opstool)

![python version](https://img.shields.io/pypi/pyversions/opstool)
![code size](https://img.shields.io/github/languages/code-size/yexiang1992/opstool)
[![code grade](https://img.shields.io/codefactor/grade/github/yexiang1992/opstool)](https://www.codefactor.io/repository/github/yexiang1992/opstool)
[![Build Status](https://scrutinizer-ci.com/g/yexiang1992/opstool/badges/build.png?b=master)](https://scrutinizer-ci.com/g/yexiang1992/opstool/build-status/master)
[![Code Intelligence Status](https://scrutinizer-ci.com/g/yexiang1992/opstool/badges/code-intelligence.svg?b=master)](https://scrutinizer-ci.com/code-intelligence)

``opstool`` is a useful toolbox package aims to help [OpenSeesPy](https://openseespydoc.readthedocs.io/en/latest/) *modelling*, *visualization*, *post-processing*, etc. 
The package is still under development.

To use, install `opstool` from [opstool-PyPI](https://pypi.org/project/opstool/):

```python
pip install --upgrade opstool
```

Python 3.9 is required.
It is recommended that you use [Anaconda](https://www.anaconda.com/) to avoid library version incompatibilities.

### Document

See [here](https://opstool.readthedocs.io/en/latest/index.html) for the full documentation.

### Vis Module

#### Based on [plotly](https://plotly.com/python/)

![CableBridgeModelVis.png](https://s2.loli.net/2022/12/02/iPhmRDaO83AVkbv.png)

![CableBridgeEigenVis.png](https://s2.loli.net/2022/12/02/3UzvQldb8CSIYJw.png)

![CableBridgeDefoVis.png](https://s2.loli.net/2022/12/02/qV2XzOkiMQTRl5D.png)

#### Based on [pyvista](https://docs.pyvista.org/)

![None.png](https://s2.loli.net/2022/12/07/TElXvIoDZFAfysc.png)

![None.png](https://s2.loli.net/2022/12/07/bMqL2kKHpN4XBeZ.png)

![EigenAnimation.gif](https://s2.loli.net/2022/12/07/akOEebwrNZCuj2V.gif)

![DefoAnimation.gif](https://s2.loli.net/2022/12/07/KVEYO6eC8hlWvXg.gif)

### Fiber section vis

![FiberSecVis.png](https://s2.loli.net/2022/12/03/jwvVecT3GCWbdBI.png)

![FiberSecVis2.png](https://s2.loli.net/2022/12/03/NQ5VOA6iUFtY9af.png)

### Fiber Section Mesh Generation

![SecMesh.png](https://s2.loli.net/2022/12/03/Jla3yTh1QxVZ9pk.png) 

### License

This software is published under the [GPLv3 license](https://www.gnu.org/licenses/gpl-3.0.en.html).

==> opstool-0.2.0.tar.gz: opstool-0.2.0/README.md <==
<p align="center">
  <font size=7><a href="https://github.com/yexiang1992/opstool">opstool</a></font>
  <p align="center"><font size=5 color=YellowGreen>modelling, visualization, post-processing for OpenSeesPy.</font></p>
</p>

[![pypi](https://img.shields.io/pypi/v/opstool)](https://pypi.org/project/opstool/)
[![Downloads](https://static.pepy.tech/badge/opstool)](https://pepy.tech/project/opstool)
[![Documentation Status](https://readthedocs.org/projects/opstool/badge/?version=latest)](https://opstool.readthedocs.io/en/latest/?badge=latest)
[![github stars](https://img.shields.io/github/stars/yexiang1992/opstool?style=social)](https://github.com/yexiang1992/opstool)
![license](https://img.shields.io/github/license/yexiang1992/opstool)

![python version](https://img.shields.io/pypi/pyversions/opstool)
![code size](https://img.shields.io/github/languages/code-size/yexiang1992/opstool)
[![code grade](https://img.shields.io/codefactor/grade/github/yexiang1992/opstool)](https://www.codefactor.io/repository/github/yexiang1992/opstool)
[![Build Status](https://scrutinizer-ci.com/g/yexiang1992/opstool/badges/build.png?b=master)](https://scrutinizer-ci.com/g/yexiang1992/opstool/build-status/master)
[![Code Intelligence Status](https://scrutinizer-ci.com/g/yexiang1992/opstool/badges/code-intelligence.svg?b=master)](https://scrutinizer-ci.com/code-intelligence)

``opstool`` is a useful toolbox package aims to help [OpenSeesPy](https://openseespydoc.readthedocs.io/en/latest/) *modelling*, *visualization*, *post-processing*, etc. 
The package is still under development.

To use, install `opstool` from [opstool-PyPI](https://pypi.org/project/opstool/):

```python
pip install --upgrade opstool
```

Python 3.9 is required for windows.
It is recommended that you use [Anaconda](https://www.anaconda.com/) to avoid library version incompatibilities.

### Document

See [here](https://opstool.readthedocs.io/en/latest/index.html) for the full documentation.

### Vis Module

#### Based on [plotly](https://plotly.com/python/)

![CableBridgeModelVis.png](https://s2.loli.net/2022/12/02/iPhmRDaO83AVkbv.png)

![CableBridgeEigenVis.png](https://s2.loli.net/2022/12/02/3UzvQldb8CSIYJw.png)

![CableBridgeDefoVis.png](https://s2.loli.net/2022/12/02/qV2XzOkiMQTRl5D.png)

#### Based on [pyvista](https://docs.pyvista.org/)

![None.png](https://s2.loli.net/2022/12/07/TElXvIoDZFAfysc.png)

![None.png](https://s2.loli.net/2022/12/07/bMqL2kKHpN4XBeZ.png)

![EigenAnimation.gif](https://s2.loli.net/2022/12/07/akOEebwrNZCuj2V.gif)

![DefoAnimation.gif](https://s2.loli.net/2022/12/07/KVEYO6eC8hlWvXg.gif)

### Fiber section vis

![FiberSecVis.png](https://s2.loli.net/2022/12/03/jwvVecT3GCWbdBI.png)

![FiberSecVis2.png](https://s2.loli.net/2022/12/03/NQ5VOA6iUFtY9af.png)

### Fiber Section Mesh Generation

![SecMesh.png](https://s2.loli.net/2022/12/03/Jla3yTh1QxVZ9pk.png) 

### License

This software is published under the [GPLv3 license](https://www.gnu.org/licenses/gpl-3.0.en.html).
